==> zio-aws-ec2_2.13-5.19.8.4-sources.jar: zio/aws/ec2/model/SendDiagnosticInterruptRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.InstanceId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class SendDiagnosticInterruptRequest(instanceId: InstanceId) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest = {
    import SendDiagnosticInterruptRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest
      .builder()
      .instanceId(InstanceId.unwrap(instanceId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.SendDiagnosticInterruptRequest.ReadOnly =
    zio.aws.ec2.model.SendDiagnosticInterruptRequest.wrap(buildAwsValue())
}
object SendDiagnosticInterruptRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.SendDiagnosticInterruptRequest =
      zio.aws.ec2.model.SendDiagnosticInterruptRequest(instanceId)
    def instanceId: InstanceId
    def getInstanceId: ZIO[Any, Nothing, InstanceId] = ZIO.succeed(instanceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest
  ) extends zio.aws.ec2.model.SendDiagnosticInterruptRequest.ReadOnly {
    override val instanceId: InstanceId =
      zio.aws.ec2.model.primitives.InstanceId(impl.instanceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest
  ): zio.aws.ec2.model.SendDiagnosticInterruptRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-7.21.15.7-sources.jar: zio/aws/ec2/model/SendDiagnosticInterruptRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.InstanceId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SendDiagnosticInterruptRequest(
    instanceId: InstanceId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest = {
    import SendDiagnosticInterruptRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest
      .builder()
      .instanceId(InstanceId.unwrap(instanceId): java.lang.String)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.SendDiagnosticInterruptRequest.ReadOnly =
    zio.aws.ec2.model.SendDiagnosticInterruptRequest.wrap(buildAwsValue())
}
object SendDiagnosticInterruptRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.SendDiagnosticInterruptRequest =
      zio.aws.ec2.model
        .SendDiagnosticInterruptRequest(instanceId, dryRun.map(value => value))
    def instanceId: InstanceId
    def dryRun: Optional[Boolean]
    def getInstanceId: ZIO[Any, Nothing, InstanceId] = ZIO.succeed(instanceId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest
  ) extends zio.aws.ec2.model.SendDiagnosticInterruptRequest.ReadOnly {
    override val instanceId: InstanceId =
      zio.aws.ec2.model.primitives.InstanceId(impl.instanceId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.SendDiagnosticInterruptRequest
  ): zio.aws.ec2.model.SendDiagnosticInterruptRequest.ReadOnly = new Wrapper(
    impl
  )
}
